==> pkgDepTools_1.8.0.zip: pkgDepTools/doc/pkgDepTools.R <==
###################################################
### chunk number 1: setup0
###################################################
options(width=72)


###################################################
### chunk number 2: setup
###################################################
library("pkgDepTools")
library("Biobase")
library("Rgraphviz")


###################################################
### chunk number 3: testMakeDepGraph0
###################################################
biocUrl <- biocReposList()["bioc"]
biocDeps <- makeDepGraph(biocUrl, type="source", dosize=FALSE)


###################################################
### chunk number 4: testMakeDepGraph
###################################################
biocDeps
edges(biocDeps)["annotate"]
## if dosize=TRUE, size in MB is stored
## as a node attribute:
## nodeData(biocDeps, n="annotate", attr="size")


###################################################
### chunk number 5: CategoryPlot
###################################################
categoryNodes <- c("Category", 
                   names(acc(biocDeps, "Category")[[1]]))
categoryGraph <- subGraph(categoryNodes, biocDeps)
nn <- makeNodeAttrs(categoryGraph, shape="ellipse")
plot(categoryGraph, nodeAttrs=nn)


###################################################
### chunk number 6: demo-setup
###################################################
allDeps <- makeDepGraph(biocReposList(), type="source",
                        keep.builtin=TRUE, dosize=FALSE)



###################################################
### chunk number 7: demo1
###################################################
getInstallOrder("GOstats", allDeps)


###################################################
### chunk number 8: demo2
###################################################
getInstallOrder("GOstats", allDeps, needed.only=FALSE)


###################################################
### chunk number 9: whoDependsOnMe
###################################################
allDepsOnMe <- reverseEdgeDirections(allDeps)
usesMethods <- dijkstra.sp(allDepsOnMe, start="methods")$distance
usesMethods <- usesMethods[is.finite(usesMethods)]
length(usesMethods) - 1 ## don't count methods itself
table(usesMethods)



###################################################
### chunk number 10: sessionInfo
###################################################
toLatex(sessionInfo())

==> pkgDepTools_1.16.0.zip: pkgDepTools/doc/pkgDepTools.R <==
###################################################
### chunk number 1: setup0
###################################################
#line 53 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKqxgbW/R.INSTALL264b45d0/pkgDepTools/inst/doc/pkgDepTools.Rnw"
options(width=72)


###################################################
### chunk number 2: setup
###################################################
#line 57 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKqxgbW/R.INSTALL264b45d0/pkgDepTools/inst/doc/pkgDepTools.Rnw"
library("pkgDepTools")
library("Biobase")
library("Rgraphviz")


###################################################
### chunk number 3: testMakeDepGraph0
###################################################
#line 92 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKqxgbW/R.INSTALL264b45d0/pkgDepTools/inst/doc/pkgDepTools.Rnw"
biocUrl <- biocReposList()["bioc"]
biocDeps <- makeDepGraph(biocUrl, type="source", dosize=FALSE)


###################################################
### chunk number 4: testMakeDepGraph
###################################################
#line 97 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKqxgbW/R.INSTALL264b45d0/pkgDepTools/inst/doc/pkgDepTools.Rnw"
biocDeps
edges(biocDeps)["annotate"]
## if dosize=TRUE, size in MB is stored
## as a node attribute:
## nodeData(biocDeps, n="annotate", attr="size")


###################################################
### chunk number 5: CategoryPlot
###################################################
#line 115 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKqxgbW/R.INSTALL264b45d0/pkgDepTools/inst/doc/pkgDepTools.Rnw"
categoryNodes <- c("Category", 
                   names(acc(biocDeps, "Category")[[1]]))
categoryGraph <- subGraph(categoryNodes, biocDeps)
nn <- makeNodeAttrs(categoryGraph, shape="ellipse")
plot(categoryGraph, nodeAttrs=nn)


###################################################
### chunk number 6: demo-setup
###################################################
#line 144 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKqxgbW/R.INSTALL264b45d0/pkgDepTools/inst/doc/pkgDepTools.Rnw"
allDeps <- makeDepGraph(biocReposList(), type="source",
                        keep.builtin=TRUE, dosize=FALSE)



###################################################
### chunk number 7: demo1
###################################################
#line 154 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKqxgbW/R.INSTALL264b45d0/pkgDepTools/inst/doc/pkgDepTools.Rnw"
getInstallOrder("GOstats", allDeps)


###################################################
### chunk number 8: demo2
###################################################
#line 161 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKqxgbW/R.INSTALL264b45d0/pkgDepTools/inst/doc/pkgDepTools.Rnw"
getInstallOrder("GOstats", allDeps, needed.only=FALSE)


###################################################
### chunk number 9: whoDependsOnMe
###################################################
#line 171 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKqxgbW/R.INSTALL264b45d0/pkgDepTools/inst/doc/pkgDepTools.Rnw"
allDepsOnMe <- reverseEdgeDirections(allDeps)
usesMethods <- dijkstra.sp(allDepsOnMe, start="methods")$distance
usesMethods <- usesMethods[is.finite(usesMethods)]
length(usesMethods) - 1 ## don't count methods itself
table(usesMethods)



###################################################
### chunk number 10: sessionInfo
###################################################
#line 181 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpKqxgbW/R.INSTALL264b45d0/pkgDepTools/inst/doc/pkgDepTools.Rnw"
toLatex(sessionInfo())
